@@ -20,8 +20,9 @@ Usage::
     list_protections_paginator: ListProtectionsPaginator = client.get_paginator("list_protections")
     ```
 """
-from typing import Iterator, List
+from typing import Generic, Iterator, List, TypeVar
 
+from botocore.paginate import PageIterator
 from botocore.paginate import Paginator as Boto3Paginator
 
 from .type_defs import (
@@ -34,9 +35,19 @@ from .type_defs import (
 __all__ = ("ListAttacksPaginator", "ListProtectionsPaginator")
 
 
+_ItemTypeDef = TypeVar("_ItemTypeDef")
+
+
+class _PageIterator(Generic[_ItemTypeDef], PageIterator):
+    def __iter__(self) -> Iterator[_ItemTypeDef]:
+        """
+        Proxy method to specify iterator item type.
+        """
+
+
 class ListAttacksPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.22/reference/services/shield.html#Shield.Paginator.ListAttacks)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/shield.html#Shield.Paginator.ListAttacks)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/paginators.html#listattackspaginator)
     """
 
@@ -47,23 +58,23 @@ class ListAttacksPaginator(Boto3Paginator):
         StartTime: "TimeRangeTypeDef" = None,
         EndTime: "TimeRangeTypeDef" = None,
         PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListAttacksResponseTypeDef]:
+    ) -> _PageIterator[ListAttacksResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.22/reference/services/shield.html#Shield.Paginator.ListAttacks.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/shield.html#Shield.Paginator.ListAttacks.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/paginators.html#listattackspaginator)
         """
 
 
 class ListProtectionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.22/reference/services/shield.html#Shield.Paginator.ListProtections)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/shield.html#Shield.Paginator.ListProtections)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/paginators.html#listprotectionspaginator)
     """
 
     def paginate(
         self, *, PaginationConfig: PaginatorConfigTypeDef = None
-    ) -> Iterator[ListProtectionsResponseTypeDef]:
+    ) -> _PageIterator[ListProtectionsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.22/reference/services/shield.html#Shield.Paginator.ListProtections.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.33/reference/services/shield.html#Shield.Paginator.ListProtections.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_shield/paginators.html#listprotectionspaginator)
         """
